@@ -1,14 +1,10 @@
-/* $XFree86$ */
-
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
 #include "stubs.h"
 
-unsigned long
+weak unsigned long
 GetTimeInMillis (void)
 {
     return 0;
 }
-
-/* end of file */
